==> geopsypack-src-3.4.1.tar.gz: geopsypack-src-3.4.1/ArrayCore/src/ConvFKRadial.h <==
/***************************************************************************
**
**  This file is part of ArrayCore.
**
**  ArrayCore is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  ArrayCore is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2018-02-02
**  Copyright: 2018-2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#ifndef CONVFKRADIAL_H
#define CONVFKRADIAL_H

#include "AbstractFKFunction.h"

namespace ArrayCore {

  class ARRAYCORE_EXPORT ConvFKRadial : public AbstractFKFunction
  {
  public:
    ConvFKRadial(FKCache * gridCache)
      : AbstractFKFunction(gridCache) {}

    virtual void resetCrossSpectrum();
    virtual void addCrossSpectrum();
    virtual void meanCrossSpectrum(int nBlocks);

    virtual double value(const Point& k) const;
    virtual double value(const Point& k, int index) const;
  };

} // namespace ArrayCore

#endif // CONVFKRADIAL_H

==> geopsypack-src-3.5.1.tar.gz: geopsypack-src-3.5.1/ArrayCore/src/ConvFKRadial.h <==
/***************************************************************************
**
**  This file is part of ArrayCore.
**
**  ArrayCore is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  ArrayCore is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2018-02-02
**  Copyright: 2018-2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#ifndef CONVFKRADIAL_H
#define CONVFKRADIAL_H

#include "ConvFKVertical.h"

namespace ArrayCore {

  class ARRAYCORE_EXPORT ConvFKRadial : public ConvFKVertical
  {
  public:
    ConvFKRadial(FKCache * cache)
      : ConvFKVertical(cache) {}

    void initialize(const FKParameters& param);

    void resetCrossSpectrum();
    void addCrossSpectrum();
    void meanCrossSpectrum(int nBlocks);
    void addIncoherentNoise(double horizontal, double);

    const ComplexMatrix * crossSpectrum() const;
    double value(const Vector<int>& index) const;
    double value(Vector<double>& k) const;
  };

} // namespace ArrayCore

#endif // CONVFKRADIAL_H
